@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::ReadmeFromPod;
-our $AUTHORITY = 'cpan:BINARY';
-$Dist::Zilla::Plugin::ReadmeFromPod::VERSION = '0.31';
+our $AUTHORITY = 'cpan:FAYLAND';
+$Dist::Zilla::Plugin::ReadmeFromPod::VERSION = '0.32';
 use Moose;
 use List::Util 1.33 qw( first );
 with 'Dist::Zilla::Role::InstallTool' => { -version => 5 }; # after PodWeaver
